@@ -78,7 +78,7 @@ final class DeleteTopicInput extends Input
     {
         $payload = [];
         if (null === $v = $this->topicArn) {
-            throw new InvalidArgument(sprintf('Missing parameter "TopicArn" for "%s". The value cannot be null.', __CLASS__));
+            throw new InvalidArgument(\sprintf('Missing parameter "TopicArn" for "%s". The value cannot be null.', __CLASS__));
         }
         $payload['TopicArn'] = $v;
 
