@@ -251,11 +251,11 @@ final class SubscribeInput extends Input
     {
         $payload = [];
         if (null === $v = $this->topicArn) {
-            throw new InvalidArgument(sprintf('Missing parameter "TopicArn" for "%s". The value cannot be null.', __CLASS__));
+            throw new InvalidArgument(\sprintf('Missing parameter "TopicArn" for "%s". The value cannot be null.', __CLASS__));
         }
         $payload['TopicArn'] = $v;
         if (null === $v = $this->protocol) {
-            throw new InvalidArgument(sprintf('Missing parameter "Protocol" for "%s". The value cannot be null.', __CLASS__));
+            throw new InvalidArgument(\sprintf('Missing parameter "Protocol" for "%s". The value cannot be null.', __CLASS__));
         }
         $payload['Protocol'] = $v;
         if (null !== $v = $this->endpoint) {
