@@ -6,6 +6,7 @@ use AsyncAws\Core\AbstractApi;
 use AsyncAws\Core\AwsError\AwsErrorFactoryInterface;
 use AsyncAws\Core\AwsError\XmlAwsErrorFactory;
 use AsyncAws\Core\Configuration;
+use AsyncAws\Core\Exception\UnsupportedRegion;
 use AsyncAws\Core\RequestContext;
 use AsyncAws\Core\Result;
 use AsyncAws\Sns\Exception\AuthorizationErrorException;
@@ -547,6 +548,44 @@ class SnsClient extends AbstractApi
         }
 
         switch ($region) {
+            case 'af-south-1':
+            case 'ap-east-1':
+            case 'ap-northeast-1':
+            case 'ap-northeast-2':
+            case 'ap-northeast-3':
+            case 'ap-south-1':
+            case 'ap-south-2':
+            case 'ap-southeast-1':
+            case 'ap-southeast-2':
+            case 'ap-southeast-3':
+            case 'ap-southeast-4':
+            case 'ap-southeast-5':
+            case 'ap-southeast-7':
+            case 'ca-central-1':
+            case 'ca-west-1':
+            case 'eu-central-1':
+            case 'eu-central-2':
+            case 'eu-north-1':
+            case 'eu-south-1':
+            case 'eu-south-2':
+            case 'eu-west-1':
+            case 'eu-west-2':
+            case 'eu-west-3':
+            case 'il-central-1':
+            case 'me-central-1':
+            case 'me-south-1':
+            case 'mx-central-1':
+            case 'sa-east-1':
+            case 'us-east-1':
+            case 'us-east-2':
+            case 'us-west-1':
+            case 'us-west-2':
+                return [
+                    'endpoint' => "https://sns.$region.amazonaws.com",
+                    'signRegion' => $region,
+                    'signService' => 'sns',
+                    'signVersions' => ['v4'],
+                ];
             case 'cn-north-1':
             case 'cn-northwest-1':
                 return [
@@ -591,6 +630,7 @@ class SnsClient extends AbstractApi
                     'signVersions' => ['v4'],
                 ];
             case 'fips-us-gov-east-1':
+            case 'us-gov-east-1':
                 return [
                     'endpoint' => 'https://sns.us-gov-east-1.amazonaws.com',
                     'signRegion' => 'us-gov-east-1',
@@ -598,6 +638,7 @@ class SnsClient extends AbstractApi
                     'signVersions' => ['v4'],
                 ];
             case 'fips-us-gov-west-1':
+            case 'us-gov-west-1':
                 return [
                     'endpoint' => 'https://sns.us-gov-west-1.amazonaws.com',
                     'signRegion' => 'us-gov-west-1',
@@ -629,11 +670,6 @@ class SnsClient extends AbstractApi
                 ];
         }
 
-        return [
-            'endpoint' => "https://sns.$region.amazonaws.com",
-            'signRegion' => $region,
-            'signService' => 'sns',
-            'signVersions' => ['v4'],
-        ];
+        throw new UnsupportedRegion(\sprintf('The region "%s" is not supported by "Sns".', $region));
     }
 }
